@@ -37,6 +37,15 @@ gen_crawl_event!(crawl_l2_event_linear, BinanceLinearWSClient, MessageType::L2Ev
 #[rustfmt::skip]
 gen_crawl_event!(crawl_l2_event_linear_option, BinanceOptionWSClient, MessageType::L2Event, subscribe_orderbook);
 
+#[rustfmt::skip]
+gen_crawl_event!(crawl_bbo_spot, BinanceSpotWSClient, MessageType::BBO, subscribe_bbo);
+#[rustfmt::skip]
+gen_crawl_event!(crawl_bbo_inverse, BinanceInverseWSClient, MessageType::BBO, subscribe_bbo);
+#[rustfmt::skip]
+gen_crawl_event!(crawl_bbo_linear, BinanceLinearWSClient, MessageType::BBO, subscribe_bbo);
+#[rustfmt::skip]
+gen_crawl_event!(crawl_bbo_linear_option, BinanceOptionWSClient, MessageType::BBO, subscribe_bbo);
+
 #[rustfmt::skip]
 gen_crawl_event!(crawl_ticker_spot, BinanceSpotWSClient, MessageType::Ticker, subscribe_ticker);
 #[rustfmt::skip]
@@ -108,6 +117,33 @@ pub(crate) fn crawl_l2_event(
     }
 }
 
+pub(crate) fn crawl_bbo(
+    market_type: MarketType,
+    symbols: Option<&[String]>,
+    on_msg: Arc<Mutex<dyn FnMut(Message) + 'static + Send>>,
+    duration: Option<u64>,
+) -> Option<std::thread::JoinHandle<()>> {
+    let all_book_ticker = vec!["!bookTicker".to_string()]; // All Book Tickers Stream
+    let symbols = if symbols.is_none() || symbols.unwrap().is_empty() {
+        Some(all_book_ticker.as_slice())
+    } else {
+        symbols
+    };
+    match market_type {
+        MarketType::Spot => crawl_bbo_spot(market_type, symbols, on_msg, duration),
+        MarketType::InverseFuture | MarketType::InverseSwap => {
+            crawl_bbo_inverse(market_type, symbols, on_msg, duration)
+        }
+        MarketType::LinearFuture | MarketType::LinearSwap => {
+            crawl_bbo_linear(market_type, symbols, on_msg, duration)
+        }
+        MarketType::EuropeanOption => {
+            crawl_bbo_linear_option(market_type, symbols, on_msg, duration)
+        }
+        _ => panic!("Binance does NOT have the {} market type", market_type),
+    }
+}
+
 pub(crate) fn crawl_ticker(
     market_type: MarketType,
     symbols: Option<&[String]>,
